# Exercicio1

**Exercicio1** é um simples pacote para armazenar ou consultar dados coletados em Python.

## Dependências
**Python 3.6** ou posterior

Pacote **numpy**


## Começando o uso
Você vai precisar instalar o pacote **Exercicio1**, para isso basta executar:
```
pip install Exercicio1
```

## Função

* `interacao ()` - pede ao usuario nome, cpf e endereco 
* `armazenamento ()` - armazena as infos do usuario em um arquivo txt
* `consulta ()` - consulta os dados do usuario a partir do seu cpf